@@ -62,7 +62,7 @@ class QHstats(object):
 
         self._set_vars = False
 
-    def __repr__(self):
+    def __str__(self):
         return "QHstats object with {} entries".format(self.size)
 
     def set_data(self, data: pd.DataFrame):
@@ -110,19 +110,25 @@ class QHstats(object):
         """Specify the observed variable (x-variable) and inferred variable (y-variable)
 
         Args:
-            xvar (str): The explanatory variable.  Can "H" for column height or "Q" for mass eruption rate.
-            yvar (str): The predicted variable.  Can "H" for column height or "Q" for mass eruption rate.
+            xvar (str): The explanatory variable.  Can be "H" for column height. Can be "Q" or "MER" for mass eruption rate.
+            yvar (str): The predicted variable.  Can be "H" for column height.  Can be "Q" or "MER" for mass eruption rate.
 
         Raises:
-            ValueError: if xvar is not "H" or "Q".
-            ValueError: if xvar is not "H" or "Q".
+            ValueError: if xvar is not "H" or "Q" or "MER".
+            ValueError: if yvar is not "H" or "Q" or "MER".
+            ValueError: if xvar == yvar.
             RuntimeError: if there are not sufficient data points in the data set to make predictions based on the explantory variable.
         """
 
-        if xvar not in ["H", "Q"]:
-            raise ValueError(f"xvar must be either H and Q, received {xvar}")
-        if yvar not in ["H", "Q"]:
-            raise ValueError(f"yvar must be either H and Q, received {yvar}")
+        if xvar not in ["H", "Q", "MER"]:
+            raise ValueError(f"xvar must be either H or Q or MER, received {xvar}")
+        if yvar not in ["H", "Q", "MER"]:
+            raise ValueError(f"yvar must be either H or Q or MER, received {yvar}")
+
+        if xvar == yvar:
+            raise ValueError(
+                f"xvar must not be the same as yvar, received {xvar}, {yvar}"
+            )
 
         self.xvar = xvar
         self.yvar = yvar
@@ -242,9 +248,9 @@ class QHstats(object):
         self.check_vars_set()
 
         if logscale:
-            self.xp = np.atleast_1d(xp)  # type: ignore
+            self.xp = np.float64(np.atleast_1d(xp))  # type: ignore
         else:
-            self.xp = np.log10(np.atleast_1d(xp))  # type: ignore
+            self.xp = np.log10(np.atleast_1d(xp), dtype=np.float64)  # type: ignore
 
         self.params()
 
@@ -449,13 +455,13 @@ class QHstats(object):
                         columns=[f"log {self.xvar}", f"log {self.yvar}"]
                     )
                     logy_col = f"log {self.yvar}"
-                    tmp_df[logy_col] = y[:, j]
+                    tmp_df[logy_col] = np.float64(y[:, j])
                     logx_col = f"log {self.xvar}"
-                    tmp_df[logx_col] = x
-                    tmp_df[self.yvar] = np.power(10, y[:, j])
-                    tmp_df[self.xvar] = np.power(10, x)
+                    tmp_df[logx_col] = np.float64(x)
+                    tmp_df[self.yvar] = np.float64(np.power(10, y[:, j]))
+                    tmp_df[self.xvar] = np.float64(np.power(10, x))
 
-                    y_df = y_df.append(tmp_df, ignore_index=True)
+                    y_df = pd.concat([y_df, tmp_df], ignore_index=True)
             else:
                 y_df = pd.DataFrame(
                     columns=[
@@ -465,11 +471,16 @@ class QHstats(object):
                         self.yvar,
                     ]
                 )
-                y_df[f"log {self.xvar}"] = self.xp
-                y_df[f"log {self.yvar}"] = y.flatten()
-                y_df[self.xvar] = np.power(10, y_df[f"log {self.xvar}"])
-                y_df[self.yvar] = np.power(10, y_df[f"log {self.yvar}"])
+                if len(self.xp) == 1:
+                    xp = self.xp * np.ones_like(y.flatten())
+                    y_df[f"log {self.xvar}"] = np.float64(xp)
+                else:
+                    y_df[f"log {self.xvar}"] = np.float64(np.repeat(self.xp, Nsamples))
+                y_df[self.xvar] = np.float64(np.power(10, y_df[f"log {self.xvar}"]))
+                y_df[f"log {self.yvar}"] = np.float64(y.flatten())
+                y_df[self.yvar] = np.float64(np.power(10, y_df[f"log {self.yvar}"]))
 
+            y_df = y_df.astype("float64")
             return y_df
 
         return y
